@@ -23,7 +23,7 @@ class PipelineTransformations(object):
     @staticmethod
     def remove_mongo_format(df: pd.DataFrame, mongo_subset_dict: dict) -> pd.DataFrame:
         for key, value in mongo_subset_dict.items():
-            df[key] = df.get(key).apply(lambda row: row.get(value))
+            df[key] = df.get(key).apply(lambda row: row.get(value) if row is not np.nan else None)
 
         return df
 
